You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2016/08/31 12:46:42 UTC

camel git commit: Jetty9: fixed typos and documentation in X-Forwarded-For

Repository: camel
Updated Branches:
  refs/heads/master c058ca543 -> e4b2c9959


Jetty9: fixed typos and documentation in X-Forwarded-For


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/e4b2c995
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/e4b2c995
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/e4b2c995

Branch: refs/heads/master
Commit: e4b2c99591f54f4d909e1e245b0c8d012c89a8c2
Parents: c058ca5
Author: Duvel <re...@dieselwalm.nl>
Authored: Wed Aug 31 13:47:37 2016 +0200
Committer: Duvel <re...@dieselwalm.nl>
Committed: Wed Aug 31 13:47:37 2016 +0200

----------------------------------------------------------------------
 .../jetty9/springboot/JettyHttpComponentConfiguration9.java  | 2 +-
 .../org/apache/camel/component/jetty/JettyHttpComponent.java | 8 ++++----
 components/camel-jetty9/src/main/docs/jetty-component.adoc   | 2 +-
 3 files changed, 6 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/e4b2c995/components-starter/camel-jetty9-starter/src/main/java/org/apache/camel/component/jetty9/springboot/JettyHttpComponentConfiguration9.java
----------------------------------------------------------------------
diff --git a/components-starter/camel-jetty9-starter/src/main/java/org/apache/camel/component/jetty9/springboot/JettyHttpComponentConfiguration9.java b/components-starter/camel-jetty9-starter/src/main/java/org/apache/camel/component/jetty9/springboot/JettyHttpComponentConfiguration9.java
index f622174..ee6fc07 100644
--- a/components-starter/camel-jetty9-starter/src/main/java/org/apache/camel/component/jetty9/springboot/JettyHttpComponentConfiguration9.java
+++ b/components-starter/camel-jetty9-starter/src/main/java/org/apache/camel/component/jetty9/springboot/JettyHttpComponentConfiguration9.java
@@ -169,7 +169,7 @@ public class JettyHttpComponentConfiguration9 {
      */
     private Integer proxyPort;
     /**
-     * To use the X-Fowarded-For header in HttpServletRequest.getRemoteAddr.
+     * To use the X-Forwarded-For header in HttpServletRequest.getRemoteAddr.
      */
     private Boolean useXForwardedForHeader;
     /**

http://git-wip-us.apache.org/repos/asf/camel/blob/e4b2c995/components/camel-jetty-common/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java
----------------------------------------------------------------------
diff --git a/components/camel-jetty9/src/main/docs/jetty-component.adoc b/components/camel-jetty9/src/main/docs/jetty-component.adoc
index 778d0d9..db50254 100644
--- a/components/camel-jetty9/src/main/docs/jetty-component.adoc
+++ b/components/camel-jetty9/src/main/docs/jetty-component.adoc
@@ -89,7 +89,7 @@ The Jetty 9 component supports 31 options which are listed below.
 | responseHeaderSize | Integer | Allows to configure a custom value of the response header size on the Jetty connectors.
 | proxyHost | String | To use a http proxy to configure the hostname.
 | proxyPort | Integer | To use a http proxy to configure the port number.
-| useXForwardedForHeader | boolean | To use the X-Fowarded-For header in HttpServletRequest.getRemoteAddr.
+| useXForwardedForHeader | boolean | To use the X-Forwarded-For header in HttpServletRequest.getRemoteAddr.
 | sendServerVersion | boolean | If the option is true jetty server will send the date header to the client which sends the request. NOTE please make sure there is no any other camel-jetty endpoint is share the same port otherwise this option may not work as expected.
 | allowJavaSerializedObject | boolean | Whether to allow java serialization when a request uses context-type=application/x-java-serialized-object This is by default turned off. If you enable this then be aware that Java will deserialize the incoming data from the request to Java and that can be a potential security risk.
 | headerFilterStrategy | HeaderFilterStrategy | To use a custom HeaderFilterStrategy to filter header to and from Camel message.
diff --git a/components/camel-jetty-common/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java b/components/camel-jetty-common/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java
index 2790bbc..9da1ffe 100644
--- a/components/camel-jetty-common/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java
+++ b/components/camel-jetty-common/src/main/java/org/apache/camel/component/jetty/JettyHttpComponent.java
@@ -999,17 +999,17 @@ public abstract class JettyHttpComponent extends HttpCommonComponent implements
     }
     
     /**
      * To use the X-Fowarded-For header in HttpServletRequest.getRemoteAddr.
      */
-    @Metadata(description = "To use the X-Fowarded-For header in HttpServletRequest.getRemoteAddr.")
+    @Metadata(description = "To use the X-Forwarded-For header in HttpServletRequest.getRemoteAddr.")
     public boolean isUseXForwardedForHeader() {
         return useXForwardedForHeader;
     }
 
     /**
-     * To use a http proxy to configure the port number.
+     * To use the X-Forwarded-For header in HttpServletRequest.getRemoteAddr.
      */
-    @Metadata(description = "To use the X-Fowarded-For header in HttpServletRequest.getRemoteAddr.")
+    @Metadata(description = "To use the X-Forwarded-For header in HttpServletRequest.getRemoteAddr.")
     public void setUseXForwardedForHeader(boolean useXForwardedForHeader) {
         this.useXForwardedForHeader = useXForwardedForHeader;
     }

http://git-wip-us.apache.org/repos/asf/camel/blob/e4b2c995/components/camel-jetty9/src/main/docs/jetty-component.adoc
----------------------------------------------------------------------
@@ -999,17 +999,17 @@ public abstract class JettyHttpComponent extends HttpCommonComponent implements
     
     /**
-     * To use the X-Fowarded-For header in HttpServletRequest.getRemoteAddr.
+     * To use the X-Forwarded-For header in HttpServletRequest.getRemoteAddr.
      */